pocketpose - PocketPose 0.0.1 documentation

Hide navigation sidebar
Hide table of contents sidebar
Back to top
Edit this page
Toggle table of contents sidebar

# `pocketpose`

## Subpackages

- `pocketpose.benchmarks`
  - `pocketpose.benchmarks.eval_coco`
  - `pocketpose.benchmarks.eval_coco_full`
  - `pocketpose.benchmarks.eval_coco_sp`
- `pocketpose.converters`
  - `pocketpose.converters.base_converter`
  - `pocketpose.converters.onnx2tf`
  - `pocketpose.converters.tf2tflite`
  - `pocketpose.converters.torch2onnx`
  - `pocketpose.converters.torch2tflite`
- `pocketpose.datasets`
  - `pocketpose.datasets.factory`
  - `pocketpose.datasets.registry`
  - `pocketpose.datasets.skeletons`
- `pocketpose.functional`
  - `pocketpose.functional.converters`
- `pocketpose.graphics`
  - `pocketpose.graphics.pose_visualizer`
- `pocketpose.models`
  - `pocketpose.models.body`
    - `pocketpose.models.body.baseline`
    - `pocketpose.models.body.efficientpose`
    - `pocketpose.models.body.efficientpose_nas`
    - `pocketpose.models.body.litehrnet`
    - `pocketpose.models.body.movenet`
    - `pocketpose.models.body.posenet`
    - `pocketpose.models.body.rtmpose`
  - `pocketpose.models.decoder`
    - `pocketpose.models.decoder.base_decoder`
    - `pocketpose.models.decoder.heatmap`
    - `pocketpose.models.decoder.posenet`
    - `pocketpose.models.decoder.simcc`
  - `pocketpose.models.interfaces`
    - `pocketpose.models.interfaces.imodel`
    - `pocketpose.models.interfaces.mmposemodel`
    - `pocketpose.models.interfaces.onnxmodel`
    - `pocketpose.models.interfaces.tflitemodel`
  - `pocketpose.models.wholebody`
    - `pocketpose.models.wholebody.blazepose`
  - `pocketpose.models.factory`
  - `pocketpose.models.registry`
- `pocketpose.utils`
  - `pocketpose.utils.stats`
    - `pocketpose.utils.stats.tflite`
  - `pocketpose.utils.io`
  - `pocketpose.utils.registry`

## Submodules

- `pocketpose.apis`
- `pocketpose.inferencer`
- `pocketpose.summarize_mmpose_model`
- `pocketpose.summarize_models`
- `pocketpose.version`

## Package Contents

### Classes

`PoseInferencer` | PoseInferencer provides a unified interface to infer poses from images.

class pocketpose.PoseInferencer(model_name, radius: float = 5, thickness: int = 3, kpt_thr: float = 0.3, draw_bbox: bool = False, return_vis: bool = False, vis_out_dir: str | None = None)

  PoseInferencer provides a unified interface to infer poses from images.

  Args:

    model_name (str): Name of the model to use radius (float): Sets the visualization keypoint radius. thickness (int): Determines the link thickness for visualization. kpt_thr (float): Sets the keypoint score threshold. Keypoints with scores exceeding

    > this threshold will be displayed.

    draw_bbox (bool): Decides whether to display the bounding boxes of instances. return_vis (bool): Decides whether to include visualization images in the results. vis_out_dir (str): Defines the folder path to save the visualization images. If unset,

    > the visualization images will not be saved.

  infer(image_path: str)

    Infer poses from an image file.

    Args:

      image_path (str): Path to the image file.